<?php
namespace Passport\Src;

use Dever;
use Passport\Lib\Base;

class Address  extends Base
{
    # 获取默认地址
    public function getDefaultAddress($uid)
    {
        $where['uid'] = $uid;
        $where['type'] = 2;
        $data = Dever::db('passport/address')->one($where);

        return $data;
    }

    # 获取某个收货地址
    public function getOne($uid, $id)
    {
        $where['uid'] = $uid;
        $where['id'] = $id;
        $data = Dever::db('passport/address')->one($where);

        if ($data && Dever::project('area')) {
            $data = $this->getInfo($data);
        }

        return $data;
    }

    # 获取地址列表
    public function getAddress($uid)
    {
        $where['uid'] = $uid;
        $data = Dever::db('passport/address')->getList($where);

        if ($data && Dever::project('area')) {
            foreach ($data as $k => $v) {
                $data[$k] = $this->getInfo($v);
            }
        }

        return $data;
    }

    private function getInfo($data)
    {
        $data['address_info'] = $data['add_string'] = $data['address'] . $data['house_number'];
        $data['province_name'] = $data['city_name'] = $data['county_name'] = $data['town_name'] = '';
        $data['town_state'] = 2;
        if ($data['town'] && $data['town'] > 0) {
            $town = Dever::db('area/town')->find($data['town']);
            if ($town) {
                $data['town_name'] = $town['name'];
                $data['town_state'] = 1;
            }
        }
        
        if ($data['county']) {

            $info = Dever::db('area/county')->find($data['county']);
            if ($info) {
                $data['county_name'] = $info['name'];
                if ($data['town_name']) {
                    $data['county_name'] .= ',' . $data['town_name'];
                }

                $data['city'] = $info['city_id'];

                $info = Dever::db('area/city')->find($data['city']);
                $data['city_name'] = $info['name'];

                $data['province'] = $info['province_id'];

                $info = Dever::db('area/province')->find($data['province']);
                $data['province_name'] = $info['name'];

                //$data['address_info'] = $data['province_name'] . $data['city_name'] . $data['county_name'] .','. $data['address'] .','. $data['house_number'];
                $data['add_string'] = $data['province_name'] . $data['city_name'] . $data['county_name'] .','. $data['address'] .','. $data['house_number'] .','. $data['contact'] .','. $data['mobile'];
            }
        }  elseif ($data['city']) {

            $info = Dever::db('area/county')->find($data['city']);
            if ($info) {
                $data['county_name'] = $info['name'];
                if ($data['town_name']) {
                    $data['county_name'] .= ',' . $data['town_name'];
                }

                $data['city'] = $info['city_id'];

                $info = Dever::db('area/city')->find($data['city']);
                $data['city_name'] = $info['name'];

                $data['province'] = $info['province_id'];

                $info = Dever::db('area/province')->find($data['province']);
                $data['province_name'] = $info['name'];

                //$data['address_info'] = $data['province_name'] . $data['city_name'] . $data['county_name'] .','. $data['address'] .','. $data['house_number'];
                $data['add_string'] = $data['province_name'] . $data['city_name'] . $data['county_name'] .','. $data['address'] .','. $data['house_number'] .','. $data['contact'] .','. $data['mobile'];
            }
            
        }
        if (!$data['county_name']) {
            $city = '';
            if (strstr($data['address'], '省')) {
                $temp = explode('省', $data['address']);
                $data['province_name'] = $temp[0] . '省';
                unset($temp[0]);
                $city = $temp[1];
            } elseif (strstr($data['address'], '市')) {
                $temp = explode('市', $data['address']);
                $data['province_name'] = $temp[0] . '市';
                $city = '';
                unset($temp[0]);
                $city = implode('市', $temp);
            } elseif (strstr($data['address'], '区')) {
                $temp = explode('区', $data['address']);
                $data['province_name'] = $temp[0] . '区';

                $city = '';
                unset($temp[0]);
                $city = implode('区', $temp);
            }

            if (strstr($city, '市')) {
                $temp = explode('市', $city);
                $data['city_name'] = $temp[0] . '市';
            }
            if (isset($temp[1])) {
                $data['county_name'] = $temp[1];
            }
        }

        return $data;
    }

    # 删除和恢复
    public function del($uid, $id, $state = 2)
    {
        $info = $this->getOne($uid, $id);
        if ($info) {
            $update['where_id'] = $info['id'];
            $update['state'] = $state;
            Dever::db('passport/address')->update($update);
        } else {
            Dever::alert('更新失败');
        }

        return 'ok';
    }

    # 添加或者更新地址接口
    public function up()
    {
        $uid = $this->check();
        $id = Dever::input('id');
        $type = Dever::input('type', 2);
        $province = Dever::input('province');
        $city = Dever::input('city');
        $county = Dever::input('county');
        $contact = Dever::input('contact');
        $address = Dever::input('address');
        $country = Dever::input('country');
        $town = Dever::input('town');
        $mobile = Dever::input('mobile');
        $sex = Dever::input('sex');
        $house_number = Dever::input('house_number');
        $tag = Dever::input('tag');

        return $this->upAddress($id, $uid, $type, $mobile, $contact, $province, $city, $county, $town, $address, $country, $sex, $house_number, $tag);
    }

    # 添加或者更新地址
    public function upAddress($id, $uid, $type = 2, $mobile, $contact, $province = '', $city = '', $county = '', $town = '', $address = '', $country = '', $sex = '', $house_number = '', $tag = '')
    {
        if ($contact) {
            $update['contact'] = $contact;
        }
        
    	if ($country) {
    		$update['country'] = $country;
    	}

        if ($mobile) {
            $update['mobile'] = $mobile;
        }

        if ($province) {
            $update['province'] = $province;
        }

        if ($city) {
            $update['city'] = $city;
        } else {
            Dever::alert('请选择城市');
        }

        if ($county) {
            $update['county'] = $county;
        }

        if ($town) {
            $update['town'] = $town;
        }
        
        if ($province && $city && $county) {
	        $update['area'] = $province . ',' . $city . ',' . $county;
        }
        if ($town) {
            $update['area'] .= ',' . $town;
        }

        $update['type'] = $type;

        if ($address) {
            $update['address'] = $address;
        }
        if ($sex) {
            $update['sex'] = $sex;
        }
        if ($house_number) {
            $update['house_number'] = $house_number;
        }
        if ($tag) {
            $update['tag'] = $tag;
        }

        if ($type == 2) {
            Dever::db('passport/address')->updateType(array('where_type' => 2, 'set_type' => 1));
        }
        
        if ($id) {
            $update['where_id'] = $id;
            Dever::db('passport/address')->update($update);
        } else {
            $update['uid'] = $uid;
            $id = Dever::db('passport/address')->insert($update);
        }



        return $id;
    }
}
