<?php
namespace Passport\Src;

use Dever;
use Passport\Lib\Base;

class App extends Base
{
    /**
     * 更新用户信息
     *
     * @return mixed
     */
    public function update()
    {
        $uid = $this->check();
        $name = Dever::input('username');
        $avatar = Dever::input('avatar');
        $sex = Dever::input('gender');
        $city = Dever::input('city');
        $title = Dever::input('title');
        $birthday = Dever::input('birthday');
        $province = Dever::input('province');
        $country = Dever::input('country');
        $desc = Dever::input('info');

        $info = Dever::load('passport/user-one', $uid);
        if ($info) {
            $update['set_username'] = $name;
            $update['set_avatar'] = $avatar;
            $update['set_sex'] = $sex;
            $update['set_city'] = $city;
            $update['set_province'] = $province;
            $update['set_country'] = $country;
            if ($desc) {
                $update['info'] = $desc;
            }
            if ($title) {
                $update['title'] = $title;
            }
            if ($birthday) {
                $update['birthday'] = Dever::maketime($birthday);
            }
            if ($country && $province && $city) {
            	$update['set_area'] = $country . ',' . $province . ',' . $city;
            }
            
            $update['where_id'] = $uid;
            Dever::load('passport/user-update', $update);
        } else {
            Dever::alert('无效的用户id,请重新登录');
        }

        $result = Dever::db('passport/user')->one($uid);
        if ($name) {
            $result['username'] = $name;
        }
        if ($avatar) {
            $result['avatar'] = $avatar;
        }
        if ($sex) {
            $result['sex'] = $sex;
        }
        if ($city) {
            $result['city'] = $city;
        }
        if ($province) {
            $result['province'] = $province;
        }
        if ($country) {
            $result['country'] = $country;
        }
        if ($country && $province && $city) {
            $result['area'] = $update['set_area'];
        }
        
        $result = $this->getSign($uid);

        return $result;
    }

    # 修改手机号
    public function update_mobile()
    {
        $uid = $this->check();
        $mobile = Dever::load('passport/reg')->checkMobileExists(false, false);

        $info = Dever::load('passport/user-one', $uid);

        if ($info) {
            $update['mobile'] = $mobile;
            $update['where_id'] = $uid;
            Dever::load('passport/user-update', $update);
        } else {
            Dever::alert('更新失败');
        }

        $result = $this->getSign($uid);

        return $result;
    }

    /**
     * 注册用户信息：app端已经拿到了openid了
     *
     * @return mixed
     */
    public function wechat_reg()
    {
        $user = array();
        $user['temp'] = 2;
        $user['username'] = Dever::input('username');
        $user['avatar'] = Dever::input('avatar');
        $user['sex'] = Dever::input('gender');
        $user['city'] = Dever::input('city');
        $user['province'] = Dever::input('province');
        $user['country'] = Dever::input('country');
        $user['county'] = Dever::input('county');
        

        $data = array();
        $data['openid'] = Dever::input('openid');
        $data['unionid'] = Dever::input('unionid');
        $data['access_token'] = Dever::input('access_token');
        $data['refresh_token'] = Dever::input('refresh_token');
        $data['expires_in'] = Dever::input('expires_in');

        $account = Dever::input('account', 1);
        $system = Dever::input('system', 1);
        $source_type = Dever::input('source_type');//即将废弃
        $system_source = Dever::input('system_source');
        $source = Dever::input('source');

        $result = $this->wechat($data, $user, $account, $system, $source_type, $system_source, $source);

        if (isset($result['uid']) && $result['uid']) {
            # 记录app登录日志
            $appData['uid'] = $result['uid'];
            $appData['source_type'] = $source_type;
            $appData['system_source'] = $system_source;
            $app = Dever::db('passport/app')->one($appData);
            if (!$app) {
                $appData['system_id'] = $system;
                Dever::db('passport/app')->insert($appData);
            }

            $this->setSystem($result['uid'], $system);
        }

        return $result;
    }

    /**
     * 生成用户或者登录
     *
     * @return int
     */
    public function login_commit()
    {
    	$mobile = Dever::input('mobile');
    	$code = Dever::input('mcode');
        $system = Dever::input('system', 1);
    	$source_type = Dever::input('source_type', 'ios');
        $system_source = Dever::input('system_source', 3);
        $type = Dever::input('type');
        $type_id = Dever::input('type_id');

        # 添加测试账号
        if ($mobile == '18710005124') {
            
        } else {
            $mobile = Dever::load('passport/reg')->checkMobileExists(false, -1);
        }
    	

        $uid = false;
        $info = Dever::db('passport/user')->one(array('mobile' => $mobile, 'system_id' => $system));
        if (!$info) {
            $data['username'] = Dever::hide($mobile);
            $data['mobile'] = $mobile;
            $data['system'] = $system;
            $data['source_type'] = $source_type;
            $data['system_source'] = $system_source;
            $uid = $this->reg($source_type, $system_source, $data);

            Dever::score($uid, 'mobile_reg', '手机号注册', false, false, false, $type, $type_id);

            if (Dever::project('message')) {
                $name = Dever::config('base', 'project')->name;
                $content = '亲爱的' . $data['username'] . '，欢迎来到' . $name;
                Dever::load('message/lib/data')->push(-1, $uid, '欢迎语', $content, $type = 1);
            }
        } else {
            $uid = $this->combine($info['id'], $mobile, 'mobile');
        }

        # 记录app登录日志
        if ($system_source == 3 || $system_source == 2) {
            $appData['uid'] = $uid;
            $appData['source_type'] = $source_type;
            $appData['system_source'] = $system_source;
            $app = Dever::db('passport/app')->one($appData);
            if (!$app) {
                $appData['system_id'] = $system;
                Dever::db('passport/app')->insert($appData);
            }
        }

        $this->setSystem($uid, $system);

        $result = $this->getSign($uid);

        //$result += Dever::db('passport/user')->one($uid);

        return $result;
    }

    /**
     * uuid登录
     *
     * @return int
     */
    public function login_uuid()
    {
        # 这里后续要加密
        $uuid = Dever::input('uuid');
        $system = Dever::input('system', 1);
        $source_type = Dever::input('source_type', 'applet');
        $system_source = Dever::input('system_source', 5);

        $appData['uuid'] = $uuid;
        $appData['source_type'] = $source_type;
        $appData['system_source'] = $system_source;
        $app = Dever::db('passport/app')->one($appData);
        if (!$app) {
            $user['username'] = '';
            $user['bind'] = 2;
            $user['temp'] = 1;
            $user['source_type'] = $source_type;
            $user['system_source'] = $system_source;
            $user['system_id'] = $system;
            $uid = Dever::db('passport/user')->insert($user);
            $this->createUsername($uid, '', true);

            $appData['uid'] = $uid;
            $appData['system_id'] = $system;
            Dever::db('passport/app')->insert($appData);
        } else {
            $uid = $app['uid'];
        }
        $this->setSystem($uid, $system);
        $result = $this->getSign($uid);

        $result += Dever::db('passport/user')->one($uid);
        return $result;
    }

    //获取用户信息
    public function user() {
        $uid = $this->check();
        $data=Dever::db('passport/user')->one($uid);
        if(!$data['pic']){
                $data['pic']=DEVER_APP_HOST . '../data/upload/pic.png';
        }
        return $data;
    }
}